@@ -67,12 +67,26 @@ def flex_add_argument_group(f):
     return f_decorated
 
 
+def flex_add_mutually_exclusive_group(f):
+    """Make add_mutually_exclusive_group accept or ignore gooey-specific options."""
+
+    def f_decorated(*args, **kwargs):
+        kwargs.pop('widget', None)
+        kwargs.pop('gooey_options', None)
+        return f(*args, **kwargs)
+
+    return f_decorated
+
+
 argparse._ActionsContainer.add_argument = flex_add_argument(
     argparse.ArgumentParser.add_argument)
 
 argparse._ActionsContainer.add_argument_group = flex_add_argument_group(
     argparse.ArgumentParser.add_argument_group)
 
+argparse._ActionsContainer.add_mutually_exclusive_group = flex_add_mutually_exclusive_group(
+    argparse.ArgumentParser.add_mutually_exclusive_group)
+
 if gooey is None or len(sys.argv) > 1:
     ArgumentParser = argparse.ArgumentParser
 
